-- Kalbids Decisions
--=======================================================================================================================
--Game_IsUsingMod
local CBPmodID = "d1b6328c-ff44-4b0d-aad7-c657f83610cd"
local CBOmodID = "8411a7a8-dad3-4622-a18e-fcc18324c799"
local CSDmodID = "eead0050-1e3f-4178-a91f-26cf1881ac39"
local EEraModID = "ce8aa614-7ef7-4a45-a179-5329869e8d6d"
local EECBPmodID  = "87b2deae-83cb-9b88-9017-79e741d3739c"

function Game_IsUsingMod(modID)
	for _, mod in pairs(Modding.GetActivatedMods()) do
		if mod.ID == modID then
			return true
		end
	end
	return false
end

local isUsingEEra = Game_IsUsingMod(EEraModID) or Game_IsUsingMod(EECBPmodID)
local isUsingCBP  = Game_IsUsingMod(CBPmodID)
-----------------------------------------
function IsInteger(n)
  return n==math.floor(n)
end
--=======================================================================================================================
-- Civ Specific Decisions
--=======================================================================================================================
-- Kalbids: Collect the jizya tax
-------------------------------------------------------------------------------------------------------------------------
local dummyOwnReligion1 = 	GameInfoTypes["BUILDING_DECISIONS_JAR_JIZYA1"]
local dummyOwnReligion2 = 	GameInfoTypes["BUILDING_DECISIONS_JAR_JIZYA2"]


local Decisions_KalbidsJizya = {}
    Decisions_KalbidsJizya.Name = "TXT_KEY_DECISIONS_JIZYA"
	Decisions_KalbidsJizya.Desc = "TXT_KEY_DECISIONS_JIZYA_DESC"
	HookDecisionCivilizationIcon(Decisions_KalbidsJizya, "CIVILIZATION_JAR_KALBIDS")
	Decisions_KalbidsJizya.CanFunc = (
	function(pPlayer)
		if pPlayer:GetCivilizationType() ~= GameInfoTypes.CIVILIZATION_JAR_KALBIDS then return false, false end
		if load(pPlayer, "Decisions_KalbidsJizya") == true then
			Decisions_KalbidsJizya.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_JIZYA_ENACTED_DESC")
			return false, false, true
		end
		local iCost = math.ceil(400*iMod)
		
		local req1 = false
		local reqIcon1 = "[ICON_UNCHECKBOX]"
		if GetPlayerMajorityReligion(pPlayer)~= nil then
			req1 = true
			reqIcon1 = "[ICON_CHECKBOX]"
		end
		
		local req2 = false
		local reqIcon2 = "[ICON_UNCHECKBOX]"
		if Teams[pPlayer:GetTeam()]:IsHasTech(GameInfoTypes.TECH_THEOLOGY) then
			req2 = true
			reqIcon2 = "[ICON_CHECKBOX]"
		end		
		Decisions_KalbidsJizya.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_JIZYA_DESC", reqIcon1, reqIcon2, iCost)
		
		if (not req1) then return true, false end
		if (not req2) then return true, false end
		if pPlayer:GetJONSCulture() < iCost then return true, false end		
		if (pPlayer:GetNumResourceAvailable(iMagistrate, false) < 1) then return true, false end		
		return true, true
	end
	)
	
	Decisions_KalbidsJizya.DoFunc = (
	function(pPlayer)
		local iCost = math.ceil(400*iMod)
		pPlayer:ChangeNumResourceTotal(iMagistrate, -1)
		pPlayer:ChangeJONSCulture(-iCost)
		pPlayer:SetNumFreePolicies(1)
		pPlayer:SetNumFreePolicies(0)
		pPlayer:SetHasPolicy(GameInfoTypes.POLICY_DECISIONS_JIZYA, true)
		save(pPlayer, "Decisions_KalbidsJizya", true)
	end
	)
	
	Decisions_KalbidsJizya.Monitors = {}
	Decisions_KalbidsJizya.Monitors[GameEvents.PlayerDoTurn] = (	
	function(playerID)
		local pPlot = Map.GetPlot(plotX, plotY)
		local pPlayer = Players[playerID]
		if load(pPlayer, "Decisions_KalbidsJizya") == true then
			for pCity in pPlayer:Cities() do
				local iFollowers = 0
				local cityPop = math.ceil(pCity:GetPopulation())
				
				for religion in GameInfo.Religions() do					
					if GetPlayerMajorityReligion(pPlayer) == religion.ID then
						iFollowers = pCity:GetNumFollowers(religion.ID)
					end
				end
				if iFollowers > 25 then iFollowers = 25 end
				pCity:SetNumRealBuilding(dummyOwnReligion1, iFollowers)
				
				local bonus = cityPop - iFollowers
				if bonus > 10 then bonus = 10 end
				pCity:SetNumRealBuilding(dummyOwnReligion2, bonus)
				Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(pCity:Plot():GetX(), pCity:Plot():GetY()))), "Jizya: +" .. bonus .. " [ICON_GOLD]; +" .. bonus .. " [ICON_PRODUCTION]", 1)
			end
		end
	end
	)

Decisions_AddCivilisationSpecific(GameInfoTypes.CIVILIZATION_JAR_KALBIDS, "Decisions_KalbidsJizya", Decisions_KalbidsJizya)

-------------------------------------------------------------------------------------------------------------------------
-- Kalbids: Construct the Royal palace
-------------------------------------------------------------------------------------------------------------------------

local buildingAlQasrID = GameInfoTypes["BUILDING_DECISIONS_JAR_ALQASR"]


local Decisions_Kalbids_AlQasr = {}
	Decisions_Kalbids_AlQasr.Name = "TXT_KEY_DECISIONS_JAR_KALBIDS_ALQASR"
	Decisions_Kalbids_AlQasr.Desc = "TXT_KEY_DECISIONS_JAR_KALBIDS_ALQASR_DESC"
	Decisions_Kalbids_AlQasr.Pedia = "TXT_KEY_DECISIONS_JAR_KALBIDS_ALQASR"
	HookDecisionCivilizationIcon(Decisions_Kalbids_AlQasr, "CIVILIZATION_JAR_KALBIDS")
	Decisions_Kalbids_AlQasr.CanFunc = (
	function(player)
		local playerID = player:GetID()
		if player:GetCivilizationType() ~= GameInfoTypes.CIVILIZATION_JAR_KALBIDS then return false, false end
		if load(player, "Decisions_Kalbids_AlQasr") == true then
			Decisions_Kalbids_AlQasr.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_JAR_KALBIDS_ALQASR_ENACTED_DESC")
			return false, false, true 
		end
		local goldCost = math.ceil(550*iMod)
		
		
		local req1 = false
		local reqIcon1 = "[ICON_UNCHECKBOX]"
		if Teams[player:GetTeam()]:IsHasTech(GameInfoTypes.TECH_PHYSICS) then
			req1 = true
			reqIcon1 = "[ICON_CHECKBOX]"
		end
		Decisions_Kalbids_AlQasr.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_JAR_KALBIDS_ALQASR_DESC", reqIcon1, goldCost)
		
		if (not req1) then return true, false end
		if player:GetGold() < goldCost then return true, false end		
		if player:GetNumResourceAvailable(iMagistrate, false) < 2 then return true, false end
		return true, true
	end
	)
	
	Decisions_Kalbids_AlQasr.DoFunc = (
	function(player)
		local playerID = player:GetID()
		local goldCost = math.ceil(550*iMod)
		player:ChangeGold(-goldCost)
		player:ChangeNumResourceTotal(iMagistrate, -2)
		player:GetCapitalCity():SetNumRealBuilding(buildingAlQasrID, 1)
		save(player, "Decisions_Kalbids_AlQasr", true)
	end
	)
	
	Decisions_Kalbids_AlQasr.Monitors = {}
	Decisions_Kalbids_AlQasr.Monitors[GameEvents.GreatPersonExpended] = (	
	function(playerID, eGreatPersonType)
		local pPlayer = Players[playerID]
		local capital = pPlayer:GetCapitalCity()
		local eraID = pPlayer:GetCurrentEra()
		local factor = 1
		if eraID == GameInfoTypes["ERA_RENAISSANCE"] then factor = 2
		elseif eraID == GameInfoTypes["ERA_INDUSTRIAL"] then factor = 4
		elseif eraID == GameInfoTypes["ERA_MODERN"] then factor = 6
		elseif eraID > GameInfo.Eras["ERA_MODERN"].ID then factor = 8
		else
		end
		if isUsingEEra then
			if eraID == GameInfoTypes["ERA_ENLIGHTENMENT"] then factor = 3 end
		end
		local bonus = 50 * factor
		local pTeamTechs = Teams[pPlayer:GetTeam()]:GetTeamTechs()
		if load(pPlayer, "Decisions_Kalbids_AlQasr") == true then
			--pPlayer:ChangeGold(bonus)
			pPlayer:ChangeJONSCulture(bonus)
			pPlayer:ChangeFaith(bonus)
			pPlayer:ChangeGoldenAgeProgressMeter(bonus)
			pTeamTechs:ChangeResearchProgress(pPlayer:GetCurrentResearch(), bonus, playerID)
			Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(capital:Plot():GetX(), capital:Plot():GetY()))), "[COLOR_YELLOW]+" .. bonus .. "[ENDCOLOR][ICON_GOLDEN_AGE]! [COLOR_CULTURE_STORED]+" .. bonus .. "[ENDCOLOR][ICON_CULTURE]! [COLOR_RESEARCH_STORED]+" .. bonus .. "[ENDCOLOR][ICON_RESEARCH]! [COLOR_WHITE]+" .. bonus .. "[ENDCOLOR][ICON_PEACE]!", 3)
		end
	end
	)
	
Decisions_AddCivilisationSpecific(GameInfoTypes.CIVILIZATION_JAR_KALBIDS, "Decisions_Kalbids_AlQasr", Decisions_Kalbids_AlQasr)


print("Arab Sicily Decisions loaded")