-- Kalbid Functions
-- Author: Jarcast
-- DateCreated: 7/21/2019 7:17:27 PM
--------------------------------------------------------------

--==========================================================================================================================
-- INCLUDES
--==========================================================================================================================
------------------------------------------------------------------------------------------------------------------------
include("FLuaVector.lua")
include("AdditionalAchievementsUtility.lua");
--include("PlotIterators.lua")
--==========================================================================================================================
-- GLOBALS
--==========================================================================================================================
----------------------------------------------------------------------------------------------------------------------------
local g_ConvertTextKey  = Locale.ConvertTextKey
local g_MapGetPlot		= Map.GetPlot
local g_MathCeil		= math.ceil
local g_MathFloor		= math.floor
local g_MathMax			= math.max
local g_MathMin			= math.min
				
local Players 			= Players
local HexToWorld 		= HexToWorld
local ToHexFromGrid 	= ToHexFromGrid
local Teams 			= Teams

local activePlayerID	= Game.GetActivePlayer()
local activePlayer		= Players[activePlayerID]
local activeTeamID		= activePlayer:GetTeam()
local activeTeam		= Teams[activeTeamID]
--==========================================================================================================================
-- UTILITIES
--==========================================================================================================================
-- CORE UTILITIES
----------------------------------------------------------------------------------------------------------------------------
--Game_IsUsingMod
local CBPmodID = "d1b6328c-ff44-4b0d-aad7-c657f83610cd"
local CBOmodID = "8411a7a8-dad3-4622-a18e-fcc18324c799"
local CSDmodID = "eead0050-1e3f-4178-a91f-26cf1881ac39"
local EEraModID = "ce8aa614-7ef7-4a45-a179-5329869e8d6d"
local EECBPmodID  = "87b2deae-83cb-9b88-9017-79e741d3739c"

function Game_IsUsingMod(modID)
	for _, mod in pairs(Modding.GetActivatedMods()) do
		if mod.ID == modID then
			return true
		end
	end
	return false
end

local isUsingEEra = Game_IsUsingMod(EEraModID) or Game_IsUsingMod(EECBPmodID)
local isUsingCBP  = Game_IsUsingMod(CBPmodID)
local isUsingCBO  = Game_IsUsingMod(CBOmodID)
local isUsingCSD  = Game_IsUsingMod(CSDmodID)
----------------------------------------------------------------------------------------------------------------------------
--HasTrait
function HasTrait(player, traitID)
	if g_IsCPActive then 
		return player:HasTrait(traitID)
	else
		local leaderType = GameInfo.Leaders[player:GetLeaderType()].Type
		local traitType  = GameInfo.Traits[traitID].Type
		for row in GameInfo.Leader_Traits("LeaderType = '" .. leaderType .. "' AND TraitType = '" .. traitType .. "'") do
			return true
		end
	end
	return false
end
------------------------------------------------------------------------------------------------------------------------
--Player_SendWorldEvent
local notificationWorldEventID = NotificationTypes["NOTIFICATION_DIPLOMACY_DECLARATION"]
function Player_SendWorldEvent(player, description, includeHuman)
	print("Sending World Event: ", description)
	local playerTeam = Teams[player:GetTeam()]
	if (not includeHuman) and player:IsHuman() then return end
	if (not playerTeam:IsHasMet(activeTeamID)) then return end
	activePlayer:AddNotification(notificationWorldEventID, description, "[COLOR_POSITIVE_TEXT]World Events[ENDCOLOR]", -1, -1)
end 
-------------------------------------------------------------------------------------------------------------------------
--Player_SendNotification
function Player_SendNotification(player, notificationType, description, descriptionShort, global, data1, data2, unitID, data3, metOnly, includesSerialMessage)
	local notificationID = NotificationTypes[notificationType]
	local teamID = player:GetTeam()
	local data1 = data1 or -1
	local data2 = data2 or -1
	local unitID = unitID or -1
	local data3 = data3 or -1
	if global then
		if (metOnly and activeTeam:IsHasMet(teamID) or (not metOnly)) then
			activePlayer:AddNotification(notificationID, description, descriptionShort, data1, data2, unitID, data3)
			if (includesSerialMessage and description) then Events.GameplayAlertMessage(description) end
		end
	else
		if (not player:IsHuman()) then return end
		if (metOnly and activeTeam:IsHasMet(teamID) or (not metOnly)) then
			activePlayer:AddNotification(notificationID, description, descriptionShort, data1, data2, unitID, data3)
			if (includesSerialMessage and description) then Events.GameplayAlertMessage(description) end
		end
	end
end   
-------------------------------------------------------------------------------------------------------------------------
--g_JFD_GlobalUserSettings_Table
local g_JFD_GlobalUserSettings_Table = {}
for row in DB.Query("SELECT Type, Value FROM JFD_GlobalUserSettings;") do 	
	g_JFD_GlobalUserSettings_Table[row.Type] = row.Value
end

--Game_GetUserSetting
function Game_GetUserSetting(type)
	return g_JFD_GlobalUserSettings_Table[type]
end
-------------------------------------------------------------------------------------------------------------------------
-- GetRandom
function GetRandom(lower, upper)
    return Game.Rand((upper + 1) - lower, "") + lower
end
-------------------------------------------------------------------------------------------------------------------------
function JFD_IsCivilisationActive(civilisationID)
	for iSlot = 0, GameDefines.MAX_MAJOR_CIVS-1, 1 do
		local slotStatus = PreGame.GetSlotStatus(iSlot)
		if (slotStatus == SlotStatus["SS_TAKEN"] or slotStatus == SlotStatus["SS_COMPUTER"]) then
			if PreGame.GetCivilization(iSlot) == civilisationID then
				return true
			end
		end
	end

	return false
end
-------------------------------------------------------------------------------------------------------------------------
function GetResourceClassFromID(identifier)
	for row in GameInfo.Resources("ID = '" .. identifier .. "'") do
		return row.ResourceClassType
	end
end
--=======================================================================================================================
-- MOD USE
--=======================================================================================================================
-- MODS
-------------------------------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------------------------------
-- SETTINGS
-------------------------------------------------------------------------------------------------------------------------
--==========================================================================================================================
-- GAME DEFINES
--==========================================================================================================================
-------------------------------------------------------------------------------------------------------------------------
--==========================================================================================================================
-- UNIQUE FUNCTIONS
--==========================================================================================================================
-- GLOBALS
--------------------------------------------------------------------------------------------------------------------------
local iMod = ((GameInfo.GameSpeeds[Game.GetGameSpeedType()].BuildPercent)/100)
local iFood = GameInfo.Yields.YIELD_FOOD.ID
local iCiv = 				GameInfoTypes["CIVILIZATION_JAR_KALBIDS"]
local traitKalbidsID =		GameInfoTypes["TRAIT_JAR_KALBIDS"]
local AqueductID = 			GameInfoTypes["BUILDING_AQUEDUCT"]
local UBQanat = 			GameInfoTypes["BUILDING_JAR_QANAT"]
local ResBloodOrangeID = 	GameInfoTypes["RESOURCE_JAR_ORANGE"]
local ResPistachioID = 		GameInfoTypes["RESOURCE_JAR_PISTACHIO"]
local ResPricklyPearID = 	GameInfoTypes["RESOURCE_JAR_PRICKLYPEAR"]
local JarFloodPlains = 		GameInfoTypes["FEATURE_FLOOD_PLAINS_JAR"]
local JarForest = 			GameInfoTypes["FEATURE_FOREST_JAR"]
local JarJungle = 			GameInfoTypes["FEATURE_JUNGLE_JAR"]
local JarMarsh = 			GameInfoTypes["FEATURE_MARSH_JAR"]
local BuildFarmID = 		GameInfoTypes["BUILD_FARM"]
local BuildPlantationID = 	GameInfoTypes["BUILD_PLANTATION"]
local JarFreshW = 			GameInfoTypes["FEATURE_JAR_FRESH_WATER"]
local KalbidsDummy = 		GameInfoTypes["BUILDING_JAR_KALBIDS"]
local SaqalibaDummy = 		GameInfoTypes["BUILDING_SAQALIBA"]
local SaqalibaID = 			GameInfoTypes["UNIT_JAR_SAQALIBA"]
local SaqalibaPromoID = 	GameInfoTypes["PROMOTION_JAR_SAQALIBA1"]

tSpecialistsID  = {}
tGreatPeopleDes = {}
for row in DB.Query("SELECT a.ID, a.Type, a.GreatPeopleUnitClass, b.Description FROM Specialists a, UnitClasses b WHERE a.GreatPeopleUnitClass = b.Type") do
	table.insert(tSpecialistsID, row.ID);
	table.insert(tGreatPeopleDes, row.Description);
end
local NumSpecialists = #tSpecialistsID
-------------------------------------------------------------------------------------------------------------------------
-- FUNCTIONS
-------------------------------------------------------------------------------------------------------------------------
-- UA: +1/2/3 Random Great People point from resources
function RandomGPPFromResources(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then	
		local bonus = 1
		if isUsingCBO and pPlayer:GetCurrentEra() >= GameInfo.Eras["ERA_INDUSTRIAL"].ID then bonus = 1.5 end
		if NumSpecialists<10 and pPlayer:GetCurrentEra() <= GameInfo.Eras["ERA_INDUSTRIAL"].ID and not isUsingCBO then bonus = 0.5 end
		
		for pCity in pPlayer:Cities() do
			local GenerP = 0
			local AdmirP = 0
			tOtherGP  = {}
			for i = 1,NumSpecialists,1 do					
				tOtherGP[i] = 0
			end
			
			for i = 0, pCity:GetNumCityPlots() - 1, 1 do
				local pPlot = pCity:GetCityIndexPlot(i)
				if pPlot:GetResourceType() ~= -1 and pPlot:GetOwner() == iPlayer then
					local rand = GetRandom(1, 2+ NumSpecialists);
					if rand ==1 then
						pPlayer:ChangeCombatExperience(bonus) -- Great General
						GenerP = GenerP + bonus
					elseif rand ==2 then		
						pPlayer:ChangeNavalCombatExperience(bonus) -- Great Admiral
						AdmirP = AdmirP + bonus
					else				
						local specialistID = tSpecialistsID[rand-2];
						pCity:ChangeSpecialistGreatPersonProgressTimes100(specialistID, bonus*100)
						tOtherGP[specialistID] = tOtherGP[specialistID] + bonus
					end
				end
			end
			if pPlayer:IsHuman() then
				if GenerP>0 then
					Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(pCity:Plot():GetX(), pCity:Plot():GetY()))), "[COLOR_GREAT_PEOPLE_STORED]+" .. GenerP .. "[ICON_GREAT_GENERAL] Great General![ENDCOLOR]", 4)
				end
				if AdmirP>0 then
					Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(pCity:Plot():GetX(), pCity:Plot():GetY()))), "[COLOR_GREAT_PEOPLE_STORED]+" .. AdmirP .. "[ICON_GREAT_ADMIRAL] Great Admiral![ENDCOLOR]", 5)
				end
				local stringtext = ""
				for i = 1,NumSpecialists,1 do
					local GPpoints = tOtherGP[tSpecialistsID[i] ]
					if GPpoints>0 then
						stringtext = "[COLOR_GREAT_PEOPLE_STORED]+" .. GPpoints .. "[ICON_GREAT_PEOPLE] " .. Locale.ConvertTextKey(tGreatPeopleDes[i]) .. "![ENDCOLOR]"
						Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(pCity:Plot():GetX(), pCity:Plot():GetY()))), stringtext, i+5)
					end
				end
			end
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(RandomGPPFromResources) end;


-- Use global variables to avoid having the event be called twice for the same plot
KalbidsUA_BuildFinished_PlayerID = 0
KalbidsUA_BuildFinished_X = 0
KalbidsUA_BuildFinished_Y = 0
KalbidsUA_Improvement = 0

function KalbidsUAFarmsIntoPlantations(playerID, iX, iY, eImprovement) -- Thanks DMS
	-- Don't continue if this is a duplicate call
	if(KalbidsUA_BuildFinished_PlayerID == playerID and KalbidsUA_BuildFinished_X == iX and KalbidsUA_BuildFinished_Y == iY and KalbidsUA_BuildFinished_Improvement == eImprovement) then
		return;
	end
	-- Store inputs for duplication check
	KalbidsUA_BuildFinished_PlayerID = playerID;
	KalbidsUA_BuildFinished_X = iX;		
	KalbidsUA_BuildFinished_Y = iY;		
	KalbidsUA_BuildFinished_Improvement = eImprovement;
	--
	local player = Players[playerID];
	local plot = Map.GetPlot(iX, iY);
	local city = player:GetCapitalCity();
	
	if(eImprovement == GameInfo.Improvements["IMPROVEMENT_FARM"].ID and player:GetCivilizationType() == iCiv and plot:GetResourceType() == -1 and plot:IsFreshWater()) then
		plot:SetImprovementType(-1)
		local numdraw2 = GetRandom(1, 3)
		if numdraw2 ==1 then
			plot:SetResourceType(ResBloodOrangeID, 1)
		elseif numdraw2 ==2 then
			plot:SetResourceType(ResPistachioID, 1)
		else
			plot:SetResourceType(ResPricklyPearID, 1)
		end
		plot:SetImprovementType(GameInfoTypes.IMPROVEMENT_PLANTATION)
	end
end
if JFD_IsCivilisationActive(iCiv) then GameEvents.BuildFinished.Add(KalbidsUAFarmsIntoPlantations) end

function KalbidsUAFarmsIntoPlantations2(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then	
		for pCity in pPlayer:Cities() do
			for i = 0, pCity:GetNumCityPlots() - 1, 1 do
				local pPlot = pCity:GetCityIndexPlot(i)
				if pPlot:GetResourceType() == -1 and pPlot:IsFreshWater() and pPlot:GetOwner() == iPlayer and pPlot:GetImprovementType() == GameInfo.Improvements["IMPROVEMENT_FARM"].ID then
					pPlot:SetImprovementType(-1)
					local numdraw2 = GetRandom(1, 3)
					if numdraw2 ==1 then
						pPlot:SetResourceType(ResBloodOrangeID, 1)
					elseif numdraw2 ==2 then
						pPlot:SetResourceType(ResPistachioID, 1)
					else
						pPlot:SetResourceType(ResPricklyPearID, 1)
					end
					pPlot:SetImprovementType(GameInfoTypes.IMPROVEMENT_PLANTATION)
				end
			end
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(KalbidsUAFarmsIntoPlantations2) end;
--======================================================================================================
-- UU: Saqaliba adds defense if garrisoned
--[[function SaqalibaDefense(iPlayer, iUnitID)
	local pPlayer = Players[iPlayer]
	local pUnit = pPlayer:GetUnitByID(iUnitID)
	local unitplot = pUnit:GetPlot()
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then
		if pUnit:IsHasPromotion(SaqalibaPromoID) then			
			for city in pPlayer:Cities() do
				local cityplot = city:Plot();
				if unitplot == cityplot and not city:IsHasBuilding(SaqalibaDummy) then
					local rescount = 0
					for i = 0, city:GetNumCityPlots() - 1, 1 do
					local pPlot = city:GetCityIndexPlot(i)
						if pPlot:GetResourceType() ~= -1  and pPlot:GetOwner() == iPlayer then
							rescount = rescount + 1
						end
					end
					city:SetNumRealBuilding(SaqalibaDummy, rescount);
				elseif  unitplot ~= cityplot  and city:IsHasBuilding(SaqalibaDummy) then
					city:SetNumRealBuilding(SaqalibaDummy, 0);
				else
				end
			end
		else
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.UnitSetXY.Add(SaqalibaDefense) end--]]

function SaqalibaDefense2(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then		
		for city in pPlayer:Cities() do
			local pUnit = city:GetGarrisonedUnit()
			if pUnit and pUnit:IsHasPromotion(SaqalibaPromoID) then
				local rescount = 0
				for i = 0, city:GetNumCityPlots() - 1, 1 do
					local pPlot = city:GetCityIndexPlot(i)
					if pPlot:GetResourceType() ~= -1  and pPlot:GetOwner() == iPlayer then
						rescount = rescount + 1
					end
				end
				if rescount > 10 then rescount = 10 end
				city:SetNumRealBuilding(SaqalibaDummy, rescount);
				--Events.AddPopupTextEvent(HexToWorld(ToHexFromGrid(Vector2(city:Plot():GetX(), city:Plot():GetY()))), "[ICON_STRENGTH]Saqaliba[ICON_STRENGTH]", 4)
			else
				city:SetNumRealBuilding(SaqalibaDummy, 0);
			end
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(SaqalibaDefense2) end

-- UU Saqaliba
function SaqalibaLuxuriesMakeStronger(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then
		local luxuryrescount =  0
		for resource in GameInfo.Resources("ResourceClassType = 'RESOURCECLASS_LUXURY'") do
			if pPlayer:GetNumResourceAvailable(resource.ID, true) > 0 then
				luxuryrescount = luxuryrescount +1
			end
		end
		for pUnit in pPlayer:Units() do
			if pUnit:IsHasPromotion(SaqalibaPromoID) then
				local iStrength = GameInfo.Units[pUnit:GetUnitType()].Combat
				if luxuryrescount <10 then
					pUnit:SetBaseCombatStrength(iStrength *(1 + 0.03*luxuryrescount) )
				else
					pUnit:SetBaseCombatStrength(iStrength *1.3)
				end
			end
		end
	end
end
if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(SaqalibaLuxuriesMakeStronger) end;


--======================================================================================================
-- UB Qanat

function QanatFreshWaterAdjacent(iPlayer, iCity, eBuilding )
	local pPlayer = Players[iPlayer]
	local pCity = pPlayer:GetCityByID(iCity)
	local pPlot = pCity:Plot()
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive() and eBuilding == UBQanat) then
		for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
			local pAdjacentPlot = Map.PlotDirection(pPlot:GetX(), pPlot:GetY(), direction)
			if pAdjacentPlot and not pAdjacentPlot:IsLake() then
				if pAdjacentPlot:GetFeatureType() == -1 and not pAdjacentPlot:IsWater() then 
					pAdjacentPlot:SetFeatureType(JarFreshW, -1);
				elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FOREST"] then 
					pAdjacentPlot:SetFeatureType(JarForest, -1);
				elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_JUNGLE"] then 
					pAdjacentPlot:SetFeatureType(JarJungle, -1);
				elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_MARSH"] then 
					pAdjacentPlot:SetFeatureType(JarMarsh, -1);
				elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FLOOD_PLAINS"] then 
					pAdjacentPlot:SetFeatureType(JarFloodPlains, -1);
				else
				end
			end	
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.CityConstructed.Add(QanatFreshWaterAdjacent) end;


function QanatFasterConstructionFarmPlantation(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then	
		for pCity in pPlayer:Cities() do
			if pCity:IsHasBuilding(UBQanat) or pCity:GetNumFreeBuilding(AqueductID) > 0 or pCity:GetNumFreeBuilding(UBQanat) > 0 then
				for i = 0, pCity:GetNumCityPlots() - 1, 1 do
					local pPlot = pCity:GetCityIndexPlot(i)
					for iPlotUnit = 0, pPlot:GetNumUnits() -1, 1 do
						local pUnit = pPlot:GetUnit(iPlotUnit)
						local iUnitOwner = pUnit:GetOwner()
						local pUnitOwner = Players[iUnitOwner]
						local workrate = pUnit:WorkRate()
						if pUnit and workrate > 1 and pPlot:GetOwner() == iPlayer then						
							local iCurrentBuildID = pUnit:GetBuildType()
							if iCurrentBuildID == BuildFarmID or iCurrentBuildID == BuildPlantationID then
								pPlot:ChangeBuildProgress(iCurrentBuildID, 2*workrate);
							end
						end
					end
				end
			end
		end	
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(QanatFasterConstructionFarmPlantation) end;


function AqueductQanatFix(iPlayer, iCity, BuildingType)
	local pPlayer = Players[iPlayer]
	local pCity =	pPlayer:GetCityByID(iCity)
	if pPlayer:GetCivilizationType() == iCiv  and BuildingType == UBQanat then
		if pCity:GetNumFreeBuilding(AqueductID) > 0 then
			return false
		end
	end
	return true
end
GameEvents.CityCanConstruct.Add(AqueductQanatFix)

local tFWcheck = {}

function AqueductQanatFix2(iPlayer)
	local pPlayer = Players[iPlayer]
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then
		for pCity in pPlayer:Cities() do
			local pPlot = pCity:Plot()				
			if pCity:GetNumFreeBuilding(AqueductID) > 0 and pCity:GetNumFreeBuilding(UBQanat) == 0 then
				pCity:SetNumRealBuilding(UBQanat, 0)
				if tFWcheck[ pCity:GetID() ] ~= true then 
					for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
						local pAdjacentPlot = Map.PlotDirection(pPlot:GetX(), pPlot:GetY(), direction)
						if pAdjacentPlot and not pAdjacentPlot:IsLake() then
							if pAdjacentPlot:GetFeatureType() == -1 and not pAdjacentPlot:IsWater() then 
								pAdjacentPlot:SetFeatureType(JarFreshW, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FOREST"] then 
								pAdjacentPlot:SetFeatureType(JarForest, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_JUNGLE"] then 
								pAdjacentPlot:SetFeatureType(JarJungle, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_MARSH"] then 
								pAdjacentPlot:SetFeatureType(JarMarsh, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FLOOD_PLAINS"] then 
								pAdjacentPlot:SetFeatureType(JarFloodPlains, -1);
							else
							end
						end
					end	
					tFWcheck[ pCity:GetID() ] = true
					print("Free Aqueduct fix done")
				end
			end				
			if pCity:GetNumFreeBuilding(UBQanat) > 0 and pCity:GetNumFreeBuilding(AqueductID) == 0 then
				if tFWcheck[ pCity:GetID() ] ~= true then 
					for direction = 0, DirectionTypes.NUM_DIRECTION_TYPES - 1, 1 do
						local pAdjacentPlot = Map.PlotDirection(pPlot:GetX(), pPlot:GetY(), direction)
						if pAdjacentPlot and not pAdjacentPlot:IsLake() then
							if pAdjacentPlot:GetFeatureType() == -1 and not pAdjacentPlot:IsWater() then 
								pAdjacentPlot:SetFeatureType(JarFreshW, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FOREST"] then 
								pAdjacentPlot:SetFeatureType(JarForest, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_JUNGLE"] then 
								pAdjacentPlot:SetFeatureType(JarJungle, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_MARSH"] then 
								pAdjacentPlot:SetFeatureType(JarMarsh, -1);
							elseif pAdjacentPlot:GetFeatureType() == GameInfoTypes["FEATURE_FLOOD_PLAINS"] then 
								pAdjacentPlot:SetFeatureType(JarFloodPlains, -1);
							else
							end
						end
					end	
					tFWcheck[ pCity:GetID() ] = true
					print("Free Qanat fix done")
				end
			end
		end
	end
end

if JFD_IsCivilisationActive(iCiv) then GameEvents.PlayerDoTurn.Add(AqueductQanatFix2) end;
--=======================================================================================================================
--TROLLER'S ADDITIONAL ACHIEVEMENTS
--=======================================================================================================================
local TAAid = "432bc547-eb05-4189-9e46-232dbde8f09f"
local isAAActive = Game_IsUsingMod(TAAid)
----------------------------------------

function UnlockKalbidsAchievement(iPlayer)
	local pPlayer = Players[iPlayer]
	if IsAAUnlocked('AA_JAR_KALBIDS_SPECIAL') then return end
	if (pPlayer:GetCivilizationType() == iCiv and pPlayer:IsAlive()) then
		if pPlayer:GetNumResourceAvailable(ResBloodOrangeID, false ) >= 10 or pPlayer:GetNumResourceAvailable(ResPistachioID, false ) >= 10 or pPlayer:GetNumResourceAvailable(ResPricklyPearID, false ) >= 10 then
			UnlockAA('AA_JAR_KALBIDS_SPECIAL')
		end
	end
end


if isAAActive then
	GameEvents.PlayerDoTurn.Add(UnlockKalbidsAchievement)
end

print("Arab Sicily functions loaded")
--==========================================================================================================================
--==========================================================================================================================
